igraph objectA helper function for simulateTumor() which returns to the user
the edge list for a DAG which is defined as an igraph object.
progressionDAG_from_igraph(iG)An igraph object for a directed acyclic graph.
A matrix with 4 columns which contains the edges of the graph as well as the rate of crossing each edge and the selective advantage/disadvantage obtained by crossing each edge.